==> JOB-3.1.2.tar.gz: JOB-3.1.2/ob/src/org/omg/CORBA/portable/ObjectImpl.java <==
// **********************************************************************
//
// Copyright (c) 1998
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// Copyright (c) 1998
// Object-Oriented Concepts GmbH
// Ettlingen, Germany
//
// All Rights Reserved
//
// **********************************************************************

package org.omg.CORBA.portable;

abstract public class ObjectImpl implements org.omg.CORBA.Object
{
    private transient Delegate delegate_;

    public Delegate
    _get_delegate()
    {
	if(delegate_ == null)
	    throw new org.omg.CORBA.BAD_OPERATION();

	return delegate_;
    }

    public void
    _set_delegate(Delegate delegate)
    {
	delegate_ = delegate;
    }

    public abstract String[]
    _ids();

    public org.omg.CORBA.ImplementationDef
    _get_implementation()
    {
	return _get_delegate().get_implementation(this);
    }

    public org.omg.CORBA.InterfaceDef
    _get_interface()
    {
	return _get_delegate().get_interface(this);
    }

    public org.omg.CORBA.Object
    _duplicate()
    {
	return _get_delegate().duplicate(this);
    }

    public void
    _release()
    {
	_get_delegate().release(this);
    }

    public boolean
    _is_a(String repository_id)
    {
	return _get_delegate().is_a(this, repository_id);
    }

    public boolean
    _is_equivalent(org.omg.CORBA.Object rhs)
    {
	return _get_delegate().is_equivalent(this, rhs);
    }

    public boolean
    _non_existent()
    {
	return _get_delegate().non_existent(this);
    }

    public int
    _hash(int maximum)
    {
	return _get_delegate().hash(this, maximum);
    }

    public org.omg.CORBA.Request
    _request(String operation)
    {
	return _get_delegate().request(this, operation);
    }

    public org.omg.CORBA.Request
    _create_request(org.omg.CORBA.Context ctx, String operation,
		    org.omg.CORBA.NVList arg_list,
		    org.omg.CORBA.NamedValue result)
    {
	return _get_delegate().create_request(this, ctx, operation,
					      arg_list, result);
    }

    public org.omg.CORBA.Request
    _create_request(org.omg.CORBA.Context ctx, String operation,
		    org.omg.CORBA.NVList arg_list,
		    org.omg.CORBA.NamedValue result,
		    org.omg.CORBA.ExceptionList excepts,
		    org.omg.CORBA.ContextList contexts)
    {
	return _get_delegate().create_request(this, ctx, operation,
					      arg_list, result,
					      excepts, contexts);
    }

    public org.omg.CORBA.ORB
    _orb()
    {
	return _get_delegate().orb(this);
    }

    public org.omg.CORBA.Policy
    _get_policy(int policy_type)
    {
	return _get_delegate().get_policy(policy_type);
    }

    public org.omg.CORBA.Policy
    _get_effective_policy_override(int policy_type)
    {
	return _get_delegate().get_effective_policy_override(policy_type);
    }

    public org.omg.CORBA.Object
    _set_policy_overrides(org.omg.CORBA.Policy[] np,
			  org.omg.CORBA.SetOverrideType set_add)
	throws org.omg.CORBA.PolicyManagerPackage.InvalidPolicies
    {
	return _get_delegate().set_policy_overrides(np, set_add);
    }

    public org.omg.CORBA.Policy[]
    _get_policy_overrides(int[] types)
    {
	return _get_delegate().get_policy_overrides(types);
    }

    public boolean
    _validate_policies(org.omg.CORBA.Policy[] inconsistent_policies)
    {
	return _get_delegate().validate_policies(inconsistent_policies);
    }

    public org.omg.CORBA.DomainManager[]
    _get_domain_managers()
    {
	return _get_delegate().get_domain_managers();
    }


    // For compatibility with Sun's JDK 1.2RC2 ORB

    public org.omg.CORBA.Object
    _get_interface_def()
    {
	return _get_interface();
    }

}

==> JOB-3.3.2.tar.gz: JOB-3.3.2/ob/src/org/omg/CORBA/portable/ObjectImpl.java <==
// **********************************************************************
//
// Copyright (c) 2000
// Object Oriented Concepts, Inc.
// Billerica, MA, USA
//
// All Rights Reserved
//
// **********************************************************************

package org.omg.CORBA.portable;

abstract public class ObjectImpl implements org.omg.CORBA.Object
{
    private transient Delegate delegate_;

    public Delegate
    _get_delegate()
    {
	if(delegate_ == null)
	    throw new org.omg.CORBA.BAD_OPERATION();

	return delegate_;
    }

    public void
    _set_delegate(Delegate delegate)
    {
	delegate_ = delegate;
    }

    public abstract String[]
    _ids();

    public org.omg.CORBA.ImplementationDef
    _get_implementation()
    {
	return _get_delegate().get_implementation(this);
    }

    public org.omg.CORBA.InterfaceDef
    _get_interface()
    {
	return _get_delegate().get_interface(this);
    }

    public org.omg.CORBA.Object
    _duplicate()
    {
	return _get_delegate().duplicate(this);
    }

    public void
    _release()
    {
	_get_delegate().release(this);
    }

    public boolean
    _is_a(String repository_id)
    {
	return _get_delegate().is_a(this, repository_id);
    }

    public boolean
    _is_equivalent(org.omg.CORBA.Object rhs)
    {
	return _get_delegate().is_equivalent(this, rhs);
    }

    public boolean
    _non_existent()
    {
	return _get_delegate().non_existent(this);
    }

    public int
    _hash(int maximum)
    {
	return _get_delegate().hash(this, maximum);
    }

    public org.omg.CORBA.Request
    _request(String operation)
    {
	return _get_delegate().request(this, operation);
    }

    public org.omg.CORBA.Request
    _create_request(org.omg.CORBA.Context ctx, String operation,
		    org.omg.CORBA.NVList arg_list,
		    org.omg.CORBA.NamedValue result)
    {
	return _get_delegate().create_request(this, ctx, operation,
					      arg_list, result);
    }

    public org.omg.CORBA.Request
    _create_request(org.omg.CORBA.Context ctx, String operation,
		    org.omg.CORBA.NVList arg_list,
		    org.omg.CORBA.NamedValue result,
		    org.omg.CORBA.ExceptionList excepts,
		    org.omg.CORBA.ContextList contexts)
    {
	return _get_delegate().create_request(this, ctx, operation,
					      arg_list, result,
					      excepts, contexts);
    }

    //
    // For compatibility with JDK 1.2
    //

    public org.omg.CORBA.Object
    _get_interface_def()
    {
	return _get_delegate().get_interface_def(this);
    }

    public org.omg.CORBA.Policy
    _get_policy(int policy_type)
    {
	return _get_delegate().get_policy(this, policy_type);
    }

    public org.omg.CORBA.Object
    _set_policy_override(org.omg.CORBA.Policy[] np,
			 org.omg.CORBA.SetOverrideType set_add)
    {
	return _get_delegate().set_policy_override(this, np, set_add);
    }

    public org.omg.CORBA.DomainManager[]
    _get_domain_managers()
    {
	return _get_delegate().get_domain_managers(this);
    }

    public org.omg.CORBA.ORB
    _orb()
    {
	return _get_delegate().orb(this);
    }

    //
    // ORBacus specific
    //

    public org.omg.CORBA.Object
    _set_policy_overrides(org.omg.CORBA.Policy[] np,
			  org.omg.CORBA.SetOverrideType set_add)
	throws org.omg.CORBA.PolicyManagerPackage.InvalidPolicies
    {
	return _get_delegate().set_policy_overrides(np, set_add);
    }

    public org.omg.CORBA.Policy
    _get_effective_policy_override(int policy_type)
    {
	return _get_delegate().get_effective_policy_override(policy_type);
    }

    public org.omg.CORBA.Policy[]
    _get_policy_overrides(int[] types)
    {
	return _get_delegate().get_policy_overrides(types);
    }

    public boolean
    _validate_policies(org.omg.CORBA.Policy[] inconsistent_policies)
    {
	return _get_delegate().validate_policies(inconsistent_policies);
    }
}
